#
# spec file for package python-dateparser
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-dateparser
VCS: https://src.suse.de/SLFO-pool/python-dateparser#ec93e389433b02b5c2f2e07e2b395766c1838b116f260e72a3c1ebf3c042b6b9
Version:        1.2.0
Release:        160000.1.9
Summary:        Date parsing library designed to parse dates from HTML pages
License:        BSD-3-Clause
URL:            https://github.com/scrapinghub/dateparser
Source:         https://files.pythonhosted.org/packages/source/d/dateparser/dateparser-%{version}.tar.gz
# PATCH-FIX-UPSTREAM mark-network-tests.patch gh#scrapinghub/dateparser#1059 mcepl@suse.com
# mark test requiring network access
Patch1:         mark-network-tests.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-python-dateutil
Requires:       python-pytz
Requires:       python-regex
Requires:       python-tzlocal
Requires(post): update-alternatives
Requires(postun):update-alternatives
Recommends:     convertdate
Recommends:     python-fasttext
Recommends:     python-langdetect
Recommends:     python-ruamel.yaml
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module convertdate}
BuildRequires:  %{python_module fasttext}
BuildRequires:  %{python_module langdetect}
BuildRequires:  %{python_module parameterized}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-dateutil}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module regex}
BuildRequires:  %{python_module ruamel.yaml}
BuildRequires:  %{python_module tzlocal}
# /SECTION
%python_subpackages

%description
Date parsing library designed to parse dates from HTML pages

%prep
%autosetup -p1 -n dateparser-%{version}

# not py3 compatible and weird license of the imported module
rm tests/test_hijri.py
rm dateparser/calendars/hijri*

sed -i '1{/\/usr\/bin\/env python/d;}' \
    dateparser_scripts/update_supported_languages_and_locales.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/dateparser-download
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export NO_NETWORK=1
# Requires files not shipped in PyPI sdist
ignoretestfiles="--ignore tests/test_dateparser_data_integrity.py"
# https://github.com/scrapinghub/dateparser/issues/1053
ignoretestfiles="$ignoretestfiles --ignore tests/test_search.py"
# overflow on 32bit
donttest="(not test_timezone_offset_calculation)"
%pytest -k "$donttest" $ignoretestfiles

%post
%python_install_alternative dateparser-download

%postun
%python_uninstall_alternative dateparser-download

%files %{python_files}
%doc AUTHORS.rst README.rst
%license LICENSE
%python_alternative %{_bindir}/dateparser-download
%{python_sitelib}/dateparser
%{python_sitelib}/dateparser_cli
%{python_sitelib}/dateparser_data
%{python_sitelib}/dateparser_scripts
%{python_sitelib}/dateparser-%{version}*-info

%changelog
* Thu Dec  7 2023 dmueller@suse.com
- update to 1.2.0:
  * New ``PREFER_MONTH_OF_YEAR`` setting (#1146)
  * Absolute years in Russian are no longer being treated as a
    number of years in the past (#1129)
  * Cleanups and internal improvements:
  * Removed the use of ``datetime.utcnow``, deprecated on Python
    3.12 (#1179)
  * Applied Black formatting to the code base (#1158)
  * Initial integration with OSSFuzz (#1198)
  * Extended test cases (#1191)
* Sat Oct 14 2023 mcepl@cepl.eu
- Clean up the SPEC file
* Thu Sep  7 2023 dmueller@suse.com
- remove unneeded GitPython dependency
* Fri Apr 21 2023 dmueller@suse.com
- add sle15_python_module_pythons (jsc#PED-68)
* Sun Mar 26 2023 dmueller@suse.com
- update to 1.1.8:
  * Improved date parsing for Chinese
  * Improved date parsing for Czech
  * Reorder language by popularity
  * Fix leak of memory in cache
  * Add support for "\d units later"
  * Move modification in CLDR data to yaml
  * Add support to use timezone via settings to get
    PREFER_DATES_FROM result
* Wed Feb 15 2023 dmueller@suse.com
- update to 1.1.7:
  * Add an “ago” synonym for Arabic
  * Improved date parsing for Czech
  * Improved date parsing for Indonesian
* Fri Jan 13 2023 dmueller@suse.com
- update to 1.1.6:
  * Fix the bug where Monday is parsed as a month
  * Prevent ReDoS in Spanish sentence splitting regex
* Mon Jan  2 2023 dmueller@suse.com
- update to 1.1.5:
  * Parse short versions of day, month, and year
  * Add a test for “in 1d”
  * Update languages_info
  * Add a workaround for zipimporter not having exec_module before Python
    3.10
  * Stabilize tests at midnight
  * Add a test case for French
  * Improved support for languages such as Slovak, Indonesian, Hindi, German
    and Japanese
  * Recursively create a model home
  * Replace regex sub with simple string replace
  * Add Python 3.10, 3.11 support
  * Drop support for Python 3.5, 3.6 versions
- drop incompatible-regex-pattern.patch (upstream)
* Mon Nov  7 2022 yarunachalam@suse.com
- Update to 1.1.3
  New features:
  * Add support for fractional units (#876)
  Improvements:
  * Fix the returned datetime skipping a day with time+timezone input and PREFER_DATES_FROM = 'future' (#1002)
  * Fix input translation breaking keep_formatting (#720)
  * English: support "till date" (#1005)
  * English: support “after” and “before” in relative dates (#1008)
  Cleanups:
  * Reorganize internal data (#1090)
  * CI updates (#1088
* Thu Oct 27 2022 yarunachalam@suse.com
- Update to 1.1.2
  * Added support for negative timestamp (#1060)
  * Fixed PytzUsageWarning for Python versions >= 3.6 (#1062)
  * Added support for dates with dots and spaces (#1028)
  * Improved support for Ukrainian, Croatian and Russian (#1072, #1074, #1079, #1082, #1073, #1083)
  * Added support for parsing Unix timestamps consistently regardless of timezones (#954)
  * Improved tests (#1086)
* Thu Aug 18 2022 code@bnavigator.de
- Clean requirements: no code coverage
* Tue May 31 2022 mmachova@suse.com
- Do not collect test_search.py
  * https://github.com/scrapinghub/dateparser/issues/1053
* Tue May 24 2022 mcepl@suse.com
- Update to 1.1.1:
  - Improvements:
  - Fixed issue with regex library by pinning dependencies to
    an earlier version
  - Extended support for Russian language dates starting with
    lowercase
  - Allowed to use_given_order for languages too
  - Fixed link to settings section
  - Defined UTF-8 encoding for Windows
  - Fixed directories creation error in CLI utils
- Update to 1.1.0:
  - New features:
  - Support language detection based on langdetect, fastText,
    or a custom implementation
  - Add support for 'by '
  - Sort default language list by internet usage
  - Improvements:
  - Improved support of Chinese
  - Improvements in search_dates
  - Make order of previous locales deterministic
  - Fix parsing with trailing space
  - Consider RETURN_TIME_AS_PERIOD for timestamp times
  - Exclude failing regex version
  - Ongoing work multithreading support
  - Add demo URL
  - QA:
  - Migrate pipelines from Travis CI to Github Actions
  - Use versioned CLDR data
  - Add a script to update table of supported languages and
    locales
  - Sort 'skip' keys in yaml files
  - Improve test coverage
  - Code cleanup
- Add patches:
  - incompatible-regex-pattern.patch (gh#scrapinghub/dateparser#1052)
  - mark-network-tests.patch (gh#scrapinghub/dateparser#1059)
* Thu Mar 17 2022 pgajdos@suse.com
- python-mock is actually not required for build
* Wed Apr  7 2021 steven.kowalik@suse.com
- Update to 1.0.0:
  * Breaking changes:
    + Drop support for Python 2.7 and pypy (see #727, #744, #748, #749, #754, #755, #758, #761, #763, #764, #777 and #783)
    + Now ``DateDataParser.get_date_data()`` returns a ``DateData`` object instead of a ``dict`` (see #778).
    + From now wrong ``settings`` are not silenced and raise ``SettingValidationError`` (see #797)
    + Now ``dateparser.parse()`` is deterministic and doesn't try previous locales. Also, ``DateDataParser.get_date_data()`` doesn't try the previous locales by default (see #781)
    + Remove the ``'base-formats'`` parser (see #721)
    + Extract the ``'no-spaces-time'`` parser from the ``'absolute-time'`` parser and make it an optional parser (see #786)
    + Remove ``numeral_translation_data`` (see #782)
    + Remove the undocumented ``SKIP_TOKENS_PARSER`` and ``FUZZY`` settings (see #728, #794)
    + Remove support for using strings in ``date_formats`` (see #726)
    + The undocumented ``ExactLanguageSearch`` class has been moved to the private scope and some internal methods have changed (see #778)
    + Changes in ``dateparser.utils``: ``normalize_unicode()`` doesn't accept ``bytes`` as input and ``convert_to_unicode`` has been deprecated (see #749)
  * New features:
    + Add Python 3.9 support (see #732, #823)
    + Detect hours separated with a period/dot (see #741)
    + Add support for "decade" (see #762)
    + Add support for the hijri calendar in Python ≥ 3.6 (see #718)
    + Fix leap years when ``PREFER_DATES_FROM`` is set (see #738)
    + Fix ``STRICT_PARSING`` setting in ``no-spaces-time`` parser (see #715)
    + Consider ``RETURN_AS_TIME_PERIOD`` setting for ``relative-time`` parser (see #807)
    + Parse the 24hr time format with meridian info (see #634)
- Remove extranous %%dir for egg-info.
* Thu Jul 30 2020 steven.kowalik@suse.com
- Update to 0.7.6:
  * Rename ``scripts`` to ``dateparser_scripts`` to avoid name collisions
    with modules from other packages or projects
  * Add Python 3.8 support
  * Implement a ``REQUIRE_PARTS`` setting
  * Add support for subscript and superscript numbers
  * Extended French support
  * Extended German support
- Switch from nose to pytest.
* Thu Apr  2 2020 mcalabkova@suse.com
- update to version 0.7.4
  * Fixed Python 2.7 tests
  * Extended Norwegian support
  * Implement a PARSERS setting
  * Add support for `PREFER_DATES_FROM` in relative/freshness parser
  * Add support for `PREFER_DAY_OF_MONTH` in base-formats parser
  * Added UTC -00:00 as a valid offset
  * Fix support for “one”
  * Fix tokenizer for non recognized characters
  * Prevent installing regex 2019.02.19
  * Added Hungarian language.
  * Added setting, `STRICT_PARSING` to ignore incomplete dates.
  * More simplifications for Russian and Ukrainian languages.
* Sat Sep 21 2019 arun@gmx.de
- specfile:
  * be more precise in %%file section
- update to version 0.7.2:
  * Features:
    + Extended Czech support
    + Added time to valid periods
    + Added timezone information to dates found with search_dates()
    + Support strings as date formats
  * Improvements:
    + Fixed Collections ABCs depreciation warning
    + Fixed dates with trailing colons not being parsed
    + Fixed date format override on any settings change
    + Fixed parsing current weekday as past date, regardless of
    settings
    + Added UTC -2:30 as a valid offset
    + Added Python 3.7 to supported versions, dropped support for
    Python 3.3 and 3.4
    + Moved to importlib from imp where possible
    + Improved support for Catalan
    + Documentation improvements
* Fri Sep 13 2019 tchvatal@suse.com
- Fix license
- Format with spec-cleaner
- Remove py2 only parts
* Wed Apr  3 2019 jayvdb@gmail.com
- Initial spec for v0.7.1
